#
# spec file for package python-django-athumb
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           python-django-athumb
Version:        2.0
Release:        10.1
Url:            http://github.com/duointeractive/django-athumb
Summary:        A simple, S3-backed thumbnailer field
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/d/django-athumb/django-athumb-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-boto
BuildRequires:  python-devel
BuildRequires:  python-django
BuildRequires:  python-Pillow
Requires:       python-boto
Requires:       python-django
Requires:       python-Pillow
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Storing images and their thumbnails on S3 is a bit of a clumbsy endeavor with
Django. While this Django app may work with more typical storage backends, it
is intended to accept image uploads, thumbnail them, and upload the original
plus the thumbs to S3. You may then get to the thumbnails in your template
by doing something like:

    <img src="{% thumbnail some_obj.image '80x80' %}" />
    
This automatically assembles the remote S3 URL to retrieve the thumbnail from.
No error checking is done, and several assumptions are made for the sake of
speed.

The primary advantage of django-athumb is that, unlike sorl and others,
thumbnails are generated at the time of user uploading the original image.
Instead of generating thumbs on-demand and making the user wait, we get that
out of the way from the beginning. This leads to a few big benefits:

* We never check for the existence of a file, after the first save/upload. We
  assume it exists, and skip a whole lot of Disk I/O trying to determine that.
  This was horrendously slow on sorl + S3, as it had to hit a remote service
  every time it wanted to know if a thumbnail needed generating.
* Since we define every possible thumbnail in advance via models.py, we have
  a defined set of possible values. They can also be more intelligently named
  than other packages. It is also possible to later add more sizes/thumbs.
* This may be ran on your own hardware with decent speed. Running it on EC2
  makes it just that much faster.

%prep
%setup -q -n django-athumb-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc AUTHORS LICENSE README.md
%{python_sitelib}/*

%changelog
* Thu May 21 2015 toddrme2178@gmail.com
- Use Pillow instead of PIL
* Wed Apr  4 2012 saschpe@suse.de
- Initial version
